### Classifiers

* Adaptive Boosting (AdaBoost),
* Bagging (Bagging),
* Extremely Randomized Trees (ExtremelyRandomizedTrees),
* Linear SVC (LinearSVC),
* Multi Layer Perceptron (MultiLayerPerceptron),
* Random Forest Classifier (RandomForest),
* Decision Tree Classifier (DecisionTree),
* K-Neighbors Classifier (KNeighbors),
* Gaussian Process Classifier (GaussianProcess),
* Gaussian Naive Bayes (GaussianNB),
* Quadratic Discriminant Analysis (QuadraticDiscriminantAnalysis).

### Feature Selection Algorithms

* Select K Best (SelectKBest),
* Select Percentile (SelectPercentile),
* Variance Threshold (VarianceThreshold).

#### Nature-Inspired based

* Bat Algorithm (BatAlgorithm),
* Differential Evolution (DifferentialEvolution),
* Self-Adaptive Differential Evolution (jDEFSTH),
* Grey Wolf Optimizer (GreyWolfOptimizer),
* Particle Swarm Optimization (ParticleSwarmOptimization).

### Feature Transformation Algorithms

* Normalizer (Normalizer),
* Standard Scaler (StandardScaler),
* Maximum Absolute Scaler (MaxAbsScaler),
* Quantile Transformer (QuantileTransformer),
* Robust Scaler (RobustScaler).

### Fitness Functions based on

* Accuracy (Accuracy),
* Cohen's kappa (CohenKappa),
* F1-Score (F1),
* Precision (Precision).

### Categorical Feature Encoders

* One-Hot Encoder (OneHotEncoder).

### Feature Imputers

* Simple Imputer (SimpleImputer).